@@ -22,6 +22,10 @@ pub fn create_empty_job_place() -> JobPlace {
     JobPlace { location: Location::Coordinate { lat: 0.0, lng: 0.0 }, duration: 0.0, times: None, tag: None }
 }
 
+pub fn create_empty_plan() -> Plan {
+    Plan { jobs: vec![], relations: None, clustering: None }
+}
+
 pub fn create_test_vehicle_type() -> VehicleType {
     VehicleType {
         type_id: "vehicle".to_string(),
