@@ -1,11 +1,11 @@
 use super::*;
-use crate::helpers::generate::create_test_vehicle_type;
-use vrp_pragmatic::format::problem::{MatrixProfile, Plan};
+use crate::helpers::generate::{create_empty_plan, create_test_vehicle_type};
+use vrp_pragmatic::format::problem::MatrixProfile;
 
 #[test]
 fn can_generate_fleet_of_specific_size() {
     let prototype = Problem {
-        plan: Plan { jobs: vec![], relations: None },
+        plan: create_empty_plan(),
         fleet: Fleet {
             vehicles: vec![create_test_vehicle_type()],
             profiles: vec![MatrixProfile { name: "normal_car".to_string(), speed: None }],
