@@ -101,7 +101,7 @@ fn can_read_full_config() {
                 MutationType::LocalSearch { probability, times, operators: inners } => {
                     assert_eq!(as_scalar_probability(probability), 0.01);
                     assert_eq!(*times, MinMaxConfig { min: 1, max: 2 });
-                    assert_eq!(inners.len(), 3);
+                    assert_eq!(inners.len(), 4);
                 }
                 _ => unreachable!(),
             }
@@ -113,6 +113,9 @@ fn can_read_full_config() {
     assert_eq!(termination.max_time, Some(300));
     assert_eq!(termination.max_generations, Some(3000));
 
+    let processing = config.processing.expect("no processing config");
+    assert_eq!(processing.len(), 3);
+
     let environment = config.environment.expect("no environment config");
     assert_eq!(environment.is_experimental, Some(false));
 
